package handler

import (
	"GtDataStore/app/cmd/organization/internal/logic/job"
	"GtDataStore/app/cmd/organization/internal/svc"
	"GtDataStore/app/model"
	"context"
	"github.com/zeromicro/go-zero/core/logx"
	"sync"
	"time"
)

func DeviceValve(ctx context.Context, task *job.Task, technologyName string) error {
	// 1. 查询所有的设备
	devices, err := findDeviceValve(task.Job.SvcCtx, int64(task.Id))
	if err != nil {
		return err
	}
	// 2. 获得点位信息
	var wg sync.WaitGroup
	wg.Add(len(devices))
	for _, device := range devices {
		device := device
		go func() {
			defer wg.Done()
			if err := device.Items.FillCurrentValue(); err != nil {
				logx.Errorf("DeviceValve device.Items.FillCurrentValue error: %s", err.Error())
			}
		}()
	}

	wg.Wait()

	// 3. 转换为存储对象
	workings, err := transDeviceValveData(devices)
	if err != nil {
		return err
	}
	// 4. 批量入库
	if _, err := task.Job.SvcCtx.WorkingValve.MultiInsert(context.Background(), workings); err != nil {
		logx.Errorf("DeviceValve task.Job.SvcCtx.WorkingValve.MultiInsert error: %s", err.Error())
	}

	return nil
}

func findDeviceValve(svcCtx *svc.ServiceContext, projectId int64) ([]model.DcDeviceBind, error) {
	if devices, err := svcCtx.DeviceBind.FindByProjectIdDeviceType(context.Background(), projectId, DEVICE_VALVE); err != nil {
		logx.Infof("findDeviceValve not found devices")
		return nil, err
	} else {
		return devices, nil
	}
}

func transDeviceValveData(datas []model.DcDeviceBind) ([]model.DcWorkingValve, error) {
	ts := make([]model.DcWorkingValve, len(datas))

	for i, data := range datas {
		ts[i] = model.DcWorkingValve{
			ProjectId:   data.ProjectId,
			DeviceCode:  data.DeviceCode,
			Adjust:      data.Items.GetItemInt64Value("adjust"),
			Opening:     data.Items.GetItemFloat64Value("opening"),
			Closed:      data.Items.GetItemInt64Value("closed"),
			Opened:      data.Items.GetItemInt64Value("opened"),
			FaultStatus: data.Items.GetItemInt64Value("fault_status"),
			CTime:       time.Now(),
		}
	}

	return ts, nil
}
